import { Readable } from 'stream';
import {
    LanguageCode, MediaEncoding
} from '@aws-sdk/client-transcribe-streaming';

/**
 * Transcribes audio data from a readable PCM audio stream into a text string using AWS Transcribe Streaming Service.
 *
 * @param {string} accessKeyId The AWS access key ID to authenticate the Transcribe client.
 * @param {string} secretAccessKey The AWS secret access key to authenticate the Transcribe client.
 * @param {string} region The AWS region where the Transcribe service is hosted.
 * @param {Readable} audioStream A readable stream of PCM audio data to be transcribed.
 * @param {LanguageCode} [languageCode='pt-BR'] The language code for the transcription (default is 'pt-BR').
 * @param {MediaEncoding} [mediaEncoding='pcm'] The encoding format of the input audio data (default is 'pcm').
 * @param {number} [sampleRate=8000] The sample rate (in Hz) of the input audio data (default is 8000Hz).
 *
 * @return {Promise<string>} A promise that resolves to the transcribed text.
 */
export  function transcribeAudioStreamToText(
    accessKeyId: string,
    secretAccessKey: string,
    region: string,
    audioStream: Readable,
    languageCode?: LanguageCode,
    mediaEncoding?: MediaEncoding,
    sampleRate?: number
): Promise<string>;
