import { Readable } from 'stream';

/**
 * Represents configurable options for FFmpeg media processing tasks.
 *
 * @property {string} [codec] - Specifies the codec to be used for encoding or decoding.
 * @property {number} [sampleRate] - Defines the audio sample rate in Hz.
 * @property {number} [channels] - Sets the number of audio channels.
 * @property {string} [format] - Determines the output media format.
 */
interface FFmpegOptions {
    codec?: string;
    sampleRate?: number;
    channels?: number;
    format?: string;
}

/**
 * Converts an audio stream to PCM (Pulse-Code Modulation) format.
 *
 * This function takes an audio input stream and converts it into PCM format
 * using specified configurations.
 *
 * @param {Readable} inputStream - A readable stream containing the audio data to be converted.
 * @param {FFmpegOptions} [options] - An optional parameter specifying FFmpeg options to configure the conversion process.
 * @return {Promise<Readable>} - A promise that resolves to a readable stream containing the PCM converted audio data.
 */
export function convertAudioToPcm(
    inputStream: Readable,
    options?: FFmpegOptions,
): Promise<Readable>;