import { Buffer } from 'node:buffer';

/**
 * Converts a PDF file buffer into an array of image buffers, where each image represents a page of the PDF.
 *
 * @param {Buffer} pdfBuffer The buffer of the PDF file to be converted to images.
 * @param {number} [density=150] The resolution density (in DPI) to use for image conversion. Defaults to 150.
 * @param {number} [quality=60] The quality level (0-100) for the converted images. Defaults to 60.
 * @return {Promise<Buffer[]>} A promise that resolves to an array of image buffers, each representing a page of the PDF.
 */
export function convertPdfBufferToImages(
    pdfBuffer: Buffer,
    density?: number,
    quality?: number,
): Promise<Buffer[]>;